summaryrefslogtreecommitdiffstats
path: root/java/sca/modules/stripes/src
diff options
context:
space:
mode:
authorantelder <antelder@13f79535-47bb-0310-9956-ffa450edef68>2009-02-18 21:30:12 +0000
committerantelder <antelder@13f79535-47bb-0310-9956-ffa450edef68>2009-02-18 21:30:12 +0000
commitac09f26b6e318b5ad422806bc9e6e2d67fdf1a57 (patch)
treec566220ad3a9682dcf72467fcea1e04d4256b02d /java/sca/modules/stripes/src
parent40ea691d2c6f067774e6e5fc3222a479240e6199 (diff)
Update some comments
git-svn-id: http://svn.us.apache.org/repos/asf/tuscany@745664 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'java/sca/modules/stripes/src')
-rw-r--r--java/sca/modules/stripes/src/main/java/org/apache/tuscany/sca/stripes/TuscanyInterceptor.java12
-rw-r--r--java/sca/modules/stripes/src/main/java/org/apache/tuscany/sca/stripes/TuscanyInterceptorSupport.java4
2 files changed, 9 insertions, 7 deletions
diff --git a/java/sca/modules/stripes/src/main/java/org/apache/tuscany/sca/stripes/TuscanyInterceptorSupport.java b/java/sca/modules/stripes/src/main/java/org/apache/tuscany/sca/stripes/TuscanyInterceptorSupport.java
index ac900ee4f3..4c73f28a08 100644
--- a/java/sca/modules/stripes/src/main/java/org/apache/tuscany/sca/stripes/TuscanyInterceptorSupport.java
+++ b/java/sca/modules/stripes/src/main/java/org/apache/tuscany/sca/stripes/TuscanyInterceptorSupport.java
@@ -29,7 +29,9 @@ import javax.servlet.ServletContext;
* <p>Base class for developing Interceptors with dependencies on SCA component references. <b>Not</b>
* to be confused with {@link TuscanyInterceptor} which injects SCA reference proxies into
* ActionBeans. For example, you may wish to subclass this class in order to write an
- * interceptor with access to Spring managed DAOs or security information.</p>
+ * interceptor with access to Tuscany ???.</p>
+ *
+ * TODO: does Tuscany really need this?
*
* <p>Since Interceptors are long-lived objects that are instantiated at application startup
* time, and not per-request, the Tuscany wiring takes place in the init() method and happens
diff --git a/java/sca/modules/stripes/src/main/java/org/apache/tuscany/sca/stripes/TuscanyInterceptor.java b/java/sca/modules/stripes/src/main/java/org/apache/tuscany/sca/stripes/TuscanyInterceptor.java
index 1c7a3001e9..1381266c9e 100644
--- a/java/sca/modules/stripes/src/main/java/org/apache/tuscany/sca/stripes/TuscanyInterceptor.java
+++ b/java/sca/modules/stripes/src/main/java/org/apache/tuscany/sca/stripes/TuscanyInterceptor.java
@@ -28,9 +28,9 @@ import net.sourceforge.stripes.util.Log;
/**
- * <p>An {@link Interceptor} that uses a Spring context to inject Spring beans into newly created
- * ActionBeans immediately following ActionBeanResolution. For more information on how the injection
- * is performed see {@link TuscanyHelper#injectBeans(Object,
+ * <p>An {@link Interceptor} that uses the implementation.web ComponentContext to inject reference
+ * proxies into newly created ActionBeans immediately following ActionBeanResolution. For more
+ * information on how the injection is performed see {@link TuscanyHelper#injectBeans(Object,
* net.sourceforge.stripes.action.ActionBeanContext)}.</p>
*
* <p>To configure the TuscanyInterceptor for use you will need to add the following to your
@@ -57,15 +57,15 @@ public class TuscanyInterceptor implements Interceptor {
/**
* Allows ActionBean resolution to proceed and then once the ActionBean has been
- * located invokes the {@link TuscanyHelper} to perform Spring based dependency injection.
+ * located invokes the {@link TuscanyHelper} to perform SCA reference injection.
*
* @param context the current execution context
* @return the Resolution produced by calling context.proceed()
* @throws Exception if the Spring binding process produced unrecoverable errors
*/
public Resolution intercept(ExecutionContext context) throws Exception {
Resolution resolution = context.proceed();
- log.debug("Running Spring dependency injection for instance of ",
+ log.debug("Running Tuscany dependency injection for instance of ",
context.getActionBean().getClass().getSimpleName());
TuscanyHelper.injectBeans(context.getActionBean(), context.getActionBeanContext());
return resolution;
@@ -57,15 +57,15 @@ public class TuscanyInterceptor implements Interceptor {
* @param context the current execution context
* @return the Resolution produced by calling context.proceed()
- * @throws Exception if the Spring binding process produced unrecoverable errors
+ * @throws Exception if the Tuscany injection process produced unrecoverable errors
*/
public Resolution intercept(ExecutionContext context) throws Exception {